@@ -88,8 +88,8 @@ def _rotate_vector_np(rot : np.ndarray, pt : np.ndarray):
 class Scene:
     def __init__(self, title : str = "My NeRF Visualizer"):
         """
-        Scene for NeRF visualization. Add objects using :code:`add_*` and :code:`set_nerf` then use 
-        :code:`export()`/:code:`display()` to create a 
+        Scene for NeRF visualization. Add objects using :code:`add_*` and :code:`set_nerf` then use
+        :code:`export()`/:code:`display()` to create a
         standalone web viewer you can open in a browser.
         Alternatively,
         use :code:`--draw` argument of the desktop volrend program or
@@ -527,8 +527,12 @@ class Scene:
             center = (self.bb_min + self.bb_max) * 0.5
         if radius is None and not np.isinf(self.bb_min).any():
             radius = (self.bb_max - self.bb_min) * 0.5
-        radius *= scale
 
+        if isinstance(center, list) or isinstance(center, tuple):
+            center = np.array(center)
+        if isinstance(radius, list) or isinstance(radius, tuple):
+            radius = np.array(radius)
+        radius *= scale
         self._update_bb(center - radius)
         self._update_bb(center + radius)
         print("* Discretizing NeRF (requires torch, tqdm, svox, scipy)")
@@ -816,10 +820,14 @@ class Scene:
 
             print(f'Serving {url}:{port}')
             import webbrowser
-            if not webbrowser.open(f'{url}:{port}'):
-                print('Could not open we bbrowser',
-                      '(note: server still launched, '
-                      'please just open given port manually, using port forarding)')
+            import threading
+            def open_webbrowser():
+                if not webbrowser.open_new(f'{url}:{port}'):
+                    print('Could not open web browser',
+                          '(note: server still launched, '
+                          'please just open given port manually, using port forarding)')
+            t=threading.Thread(target=open_webbrowser)
+            t.start()
             server.serve_forever()
 
     def display(self, *args, **kwargs):
